MicroSiteCompetencyItemDataModel class
Constructors
-
MicroSiteCompetencyItemDataModel({required String id, String? type, String? name, String? displayName, String? description, String? status, String? count, List<
MicroSiteCompetencyItemDataModel> ? children}) -
MicroSiteCompetencyItemDataModel.fromJson(Map<
String, dynamic> json, {bool useCompetencyv6 = false}) -
factory
Properties
-
children
↔ List<
MicroSiteCompetencyItemDataModel> ? -
getter/setter pair
- count ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
- type ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited