MicroSiteInsightsData class

Constructors

MicroSiteInsightsData({String? icon, String? iconColor, String? value, String? valueColor, String? label, String? labelColor, String? background})
MicroSiteInsightsData.fromJson(Map<String, dynamic> json)
factory

Properties

background String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon String?
getter/setter pair
iconColor String?
getter/setter pair
label String?
getter/setter pair
labelColor String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
getter/setter pair
valueColor String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited