MicroSiteBannerSliderDataModel class

Constructors

MicroSiteBannerSliderDataModel({bool? active, Map<String, String>? banners, String? title})
MicroSiteBannerSliderDataModel.fromJson(Map<String, dynamic> json)

Properties

active bool?
getter/setter pair
banners Map<String, String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited